Library Usage
=============

Some facts about this library:

  - setup from a CRUD (Create Read Update Delete) perspective
  - lightly setup as a pyramid extension / add-on
  - minimally uses the component architecture (`zope.interface <https://pypi.python.org/pypi/zope.interface>`_)

